Learn R Programming

epi2me2r (version 0.1.0)

amr_raw_to_phyloseq: Raw AMR files plus metadata to phyloseq object

Description

given directory and metadata make phyloseq object phyloseq package required.

Arguments

path.to.amr.files

path to data of raw csv files from ARMA CARD analysis

metdata

data.table of metadata with "arma_filename" and "arma_barcode" columns required

coveragenumber

Minimum percentage of a gene that must be covered. Range from 0 to 99, default = 80

keepSNP

TRUE or FALSE: whether to keep AMR gene conferred by one SNP change, default = FALSE

Value

phyloseq object for downstream analysis

See Also

phyloseq

Examples

Run this code
# NOT RUN {
amr_raw_to_phyloseq(path.to.amr.files = path/to/amr.count.table,
metadata = metadata, coveragenumber = 80, keepSNP = FALSE)
# }

Run the code above in your browser using DataLab