Learn R Programming

epi2me2r (version 0.1.0)

amr_read_taxonomy: assign taxonomy for phylogenetic and AMR for each read

Description

Given raw data for AMR and WIMP, provides full AMR and taxon info for those reads that assign to both

Arguments

path.to.wimp.files

path to folder containing raw CSV files from WIMP analysis

path.to.amr.files

path to folder containing raw CSV files from ARMA analysis

coveragenumber

Minimum percentage of a gene that must be covered. Range from 0 to 99, default = 80

Value

data.frame with double classified reads

Examples

Run this code
# NOT RUN {
amr_read_taxonomy(path.to.wimp.files = "path/to/wimp_files",
path.to.amr.files = "path/to/amr_files", coveragenumber = 80)
# }

Run the code above in your browser using DataLab