Learn R Programming

epi2me2r (version 0.1.0)

read_in_amr_files: Convert raw AMR CSV files to data table

Description

Convert raw AMR CSV files to data table

Arguments

path.to.amr.files

path to folder containing raw CSV files from ARMA CARD analysis

coveragenumber

Minimum percentage of a gene that must be covered. Range from 0 to 99, default = 80

keepSNP

TRUE or FALSE: whether to keep AMR gene conferred by one SNP change, default = FALSE

Value

data.table of AMR genes at a specific coverage with or without SNP associated

Examples

Run this code
# NOT RUN {
read_in_amr_files(path.to.amr.files = "~/Desktop/my.files/",
coveragenumber = 80, keepSNP = FALSE)
# }

Run the code above in your browser using DataLab