Learn R Programming

epi2me2r (version 0.1.0)

wimp_raw_to_phyloseq: Raw WIMP files plus metadata to phyloseq object

Description

Given wimp directory and metadata, make phyloseq object. phyloseq package required.

Usage

wimp_raw_to_phyloseq(
  path.to.wimp.files,
  metadata,
  keep.unclassified = FALSE,
  keep.human = FALSE
)

Arguments

path.to.wimp.files

path to data of raw csv files from WIMP analysis

metadata

dataframe of metadata with "filename" and "barcode" columns required

keep.unclassified

TRUE or FALSE: whether to keep reads that do not classify below phylum, default = FALSE

keep.human

TRUE or FALSE: whether to keep reads that are classified as human, default = FALSE

Value

phyloseq object for downstream analysis with WIMP data

See Also

phyloseq

Examples

Run this code
# NOT RUN {
wimp_raw_to_phyloseq(path.to.wimp.files = path/to/wimpfiles,
metadata = metadata, keep.unclassified = FALSE, keep.human = FALSE)
# }

Run the code above in your browser using DataLab