powered by
given directory and metadata make phyloseq object phyloseq package required.
path to data of raw csv files from ARMA CARD analysis
data.table of metadata with "arma_filename" and "arma_barcode" columns required
Minimum percentage of a gene that must be covered. Range from 0 to 99, default = 80
TRUE or FALSE: whether to keep AMR gene conferred by one SNP change, default = FALSE
phyloseq object for downstream analysis
phyloseq
# NOT RUN { amr_raw_to_phyloseq(path.to.amr.files = path/to/amr.count.table, metadata = metadata, coveragenumber = 80, keepSNP = FALSE) # }
Run the code above in your browser using DataLab