powered by
Given raw data for AMR and WIMP, provides full AMR and taxon info for those reads that assign to both
path to folder containing raw CSV files from WIMP analysis
path to folder containing raw CSV files from ARMA analysis
Minimum percentage of a gene that must be covered. Range from 0 to 99, default = 80
data.frame with double classified reads
# NOT RUN { amr_read_taxonomy(path.to.wimp.files = "path/to/wimp_files", path.to.amr.files = "path/to/amr_files", coveragenumber = 80) # }
Run the code above in your browser using DataLab