powered by
Convert raw AMR CSV files to data table
path to folder containing raw CSV files from ARMA CARD analysis
Minimum percentage of a gene that must be covered. Range from 0 to 99, default = 80
TRUE or FALSE: whether to keep AMR gene conferred by one SNP change, default = FALSE
data.table of AMR genes at a specific coverage with or without SNP associated
# NOT RUN { read_in_amr_files(path.to.amr.files = "~/Desktop/my.files/", coveragenumber = 80, keepSNP = FALSE) # }
Run the code above in your browser using DataLab