powered by
Given wimp directory and metadata, make phyloseq object. phyloseq package required.
wimp_raw_to_phyloseq( path.to.wimp.files, metadata, keep.unclassified = FALSE, keep.human = FALSE )
path to data of raw csv files from WIMP analysis
dataframe of metadata with "filename" and "barcode" columns required
TRUE or FALSE: whether to keep reads that do not classify below phylum, default = FALSE
TRUE or FALSE: whether to keep reads that are classified as human, default = FALSE
phyloseq object for downstream analysis with WIMP data
phyloseq
# NOT RUN { wimp_raw_to_phyloseq(path.to.wimp.files = path/to/wimpfiles, metadata = metadata, keep.unclassified = FALSE, keep.human = FALSE) # }
Run the code above in your browser using DataLab